# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.2.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system

from winrt.windows.foundation.metadata import AttributeTargets, CompositionType, DeprecationType, FeatureStage, GCPressureAmount, MarshalingType, Platform, ThreadingModel

Self = typing.TypeVar('Self')

@typing.final
class ApiInformation_Static(type):
    @typing.overload
    def is_api_contract_present(cls, contract_name: str, major_version: winrt.system.UInt16, /) -> bool: ...
    @typing.overload
    def is_api_contract_present(cls, contract_name: str, major_version: winrt.system.UInt16, minor_version: winrt.system.UInt16, /) -> bool: ...
    def is_enum_named_value_present(cls, enum_type_name: str, value_name: str, /) -> bool: ...
    def is_event_present(cls, type_name: str, event_name: str, /) -> bool: ...
    @typing.overload
    def is_method_present(cls, type_name: str, method_name: str, /) -> bool: ...
    @typing.overload
    def is_method_present(cls, type_name: str, method_name: str, input_parameter_count: winrt.system.UInt32, /) -> bool: ...
    def is_property_present(cls, type_name: str, property_name: str, /) -> bool: ...
    def is_read_only_property_present(cls, type_name: str, property_name: str, /) -> bool: ...
    def is_type_present(cls, type_name: str, /) -> bool: ...
    def is_writeable_property_present(cls, type_name: str, property_name: str, /) -> bool: ...

@typing.final
class ApiInformation(winrt.system.Object, metaclass=ApiInformation_Static):
    pass




# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.2.0

import enum

import winrt.system
from winrt import _winrt_windows_foundation_metadata

__all__ = [
    "AttributeTargets",
    "CompositionType",
    "DeprecationType",
    "FeatureStage",
    "GCPressureAmount",
    "MarshalingType",
    "Platform",
    "ThreadingModel",
    "ApiInformation",
]

class AttributeTargets(enum.IntFlag):
    ALL = 0xFFFFFFFF
    DELEGATE = 0x1
    ENUM = 0x2
    EVENT = 0x4
    FIELD = 0x8
    INTERFACE = 0x10
    METHOD = 0x40
    PARAMETER = 0x80
    PROPERTY = 0x100
    RUNTIME_CLASS = 0x200
    STRUCT = 0x400
    INTERFACE_IMPL = 0x800
    API_CONTRACT = 0x2000

class CompositionType(enum.IntEnum):
    PROTECTED = 1
    PUBLIC = 2

class DeprecationType(enum.IntEnum):
    DEPRECATE = 0
    REMOVE = 1

class FeatureStage(enum.IntEnum):
    ALWAYS_DISABLED = 0
    DISABLED_BY_DEFAULT = 1
    ENABLED_BY_DEFAULT = 2
    ALWAYS_ENABLED = 3

class GCPressureAmount(enum.IntEnum):
    LOW = 0
    MEDIUM = 1
    HIGH = 2

class MarshalingType(enum.IntEnum):
    NONE = 1
    AGILE = 2
    STANDARD = 3
    INVALID_MARSHALING = 0

class Platform(enum.IntEnum):
    WINDOWS = 0
    WINDOWS_PHONE = 1

class ThreadingModel(enum.IntEnum):
    S_T_A = 1
    M_T_A = 2
    BOTH = 3
    INVALID_THREADING = 0

ApiInformation = _winrt_windows_foundation_metadata.ApiInformation
